@@ -425,29 +425,29 @@ class Chemical:
         Dictionary-like object with functional group numerical
         identifiers as keys and the number of groups as values.
     mu(phase, T, P) : 
-        Dynamic viscosity functor [Pa*s].
+        Dynamic viscosity [Pa*s].
     kappa(phase, T, P): 
-        Thermal conductivity functor [W/m/K].
+        Thermal conductivity [W/m/K].
     V(phase, T, P): 
-        Molar volume functor [m^3/mol].
+        Molar volume [m^3/mol].
     Cn(phase, T) : 
-        Molar heat capacity functor [J/mol/K].
+        Molar heat capacity [J/mol/K].
     Psat(T) : 
-        Vapor pressure functor [Pa].
+        Vapor pressure [Pa].
     Hvap(T) : 
-        Heat of vaporization functor [J/mol]
+        Heat of vaporization [J/mol]
     sigma(T) : 
-        Surface tension functor [N/m].
+        Surface tension [N/m].
     epsilon : 
-        Relative permitivity functor [-]
+        Relative permitivity [-]
     S(phase, T, P) : 
-        Entropy functor [J/mol].
+        Entropy [J/mol].
     H(phase, T) : 
-        Enthalpy functor [J/mol].
+        Enthalpy [J/mol].
     S_excess(T, P) : 
-        Excess entropy functor [J/mol].
+        Excess entropy [J/mol].
     H_excess(T, P) : 
-        Excess enthalpy functor [J/mol].
+        Excess enthalpy [J/mol].
     phase_ref : {'s', 'l', 'g'}
         Phase at 298 K and 101325 Pa.
     MW : float
@@ -1050,7 +1050,8 @@ class Chemical:
                             single_phase and self.phase_ref)
     
     def get_missing_slots(self, slots=None):
-        """Return a list all missing thermodynamic properties.
+        """
+        Return a list all missing thermodynamic properties.
         
         Examples
         --------
@@ -1198,7 +1199,7 @@ class Chemical:
         >>> from thermosteam import Chemical
         >>> N2 = Chemical('N2')
         >>> N2.at_state(phase='g')
-        >>> N2.show() # Note how all functors are not a function of phase anymore
+        >>> N2.show() # Note how all models are not a function of phase anymore
         Chemical: N2 (phase_ref='g') at phase='g'
         [Names]  CAS: 7727-37-9
                  InChI: N2/c1-2
