@@ -58,22 +58,62 @@ def functor_base_and_params(function):
 
 # %% Decorator
   
-def functor(function=None, var=None, wrap=None, **autodoc):
-    """Return a Functor subclass from function."""
-    if function:
-        base, params = functor_base_and_params(function)
+def functor(f=None, var=None, wrap=None, **autodoc):
+    """
+    Decorate a function of temperature, or both temperature and pressure as a Functor subclass.
+    
+    Parameters
+    ----------
+    f : function(T, *args) or function(T, P, *args)
+        Function that calculate a thermodynamic property based on temperature,
+        or both temperature and pressure.
+    var : str, optional
+        Name of variable returned (useful for bookkeeping).
+    wrap : function
+        Should return a dictionary of arguments to pass to the fist function argument.
+    **autodoc : 
+        Options to autodoc Functor subclass. By default, Functor subclass is not automatically documented.
+    
+    Notes
+    -----
+    The functor decorator checks the signature of the function to find the 
+    names of the parameters that should be stored as data. 
+    
+    Examples
+    --------
+	Create a functor of temperature that returns the vapor pressure
+	in Pascal:
+	
+    >>> # Describe the return value with `var`.
+    >>> # Thermosteam's chemical units of measure are always assumed.
+    >>> @functor(var='Psat')
+    ... def Antoine(T, a, b, c):
+    ...     return 10.0**(a - b / (T + c))
+    >>> f = Antoine(a=10.116, b=1687.5, c=-42.98)
+    >>> f
+    Functor: Antoine(T, P=None) -> Psat [Pa]
+     a: 10.116
+     b: 1687.5
+     c: -42.98
+    >>> f(T=373.15)
+    101047.25357066597
+    
+    
+    """
+    if f:
+        base, params = functor_base_and_params(f)
         dct = {'__slots__': (),
-               'function': staticmethod(function),
+               'function': staticmethod(f),
                'params': params,
                'var': var}
-        cls = type(function.__name__, (base,), dct)
+        cls = type(f.__name__, (base,), dct)
         cls._autodoc_ = autodoc
         if wrap: cls.wrapper(wrap, **autodoc)
         elif autodoc: autodoc_functor(cls, **autodoc)
-        cls.__module__ = function.__module__
+        cls.__module__ = f.__module__
         return cls
     else:
-        return lambda function: functor(function, var, wrap, **autodoc)
+        return lambda f: functor(f, var, wrap, **autodoc)
 
 
 # %% Decorators
