@@ -139,7 +139,7 @@ def plot_lle_ternary_diagram(carrier, solvent, solute, T, P=101325, thermo=None,
     Examples
     --------
     >>> # from thermosteam import equilibrium as eq
-    >>> # plot_lle_ternary_diagram('Water', 'Ethanol', 'EthylAcetate', T=298.15)
+    >>> # eq.plot_lle_ternary_diagram('Water', 'Ethanol', 'EthylAcetate', T=298.15)
     
     .. figure:: ../images/water_ethanol_ethyl_acetate_ternary_diagram.png
 
