@@ -1,15 +1,13 @@
 # -*- coding: utf-8 -*-
-"""
-Created on Mon Nov 25 20:55:06 2019
+from .utils import colors
 
-@author: yoelr
-"""
 __all__ = ('UndefinedChemical',
            'UndefinedPhase',
            'UndefinedPhaseOrChemical',
            'DimensionError',
-           'AutodocError',
-           'DeprecatedAttribute')
+           'message_with_object_stamp',
+           'try_method_with_object_stamp',
+           'raise_error_with_object_stamp')
 
 class UndefinedChemical(AttributeError):
     """AttributeError regarding undefined chemicals."""
@@ -26,11 +24,20 @@ class UndefinedPhaseOrChemical(AttributeError):
 class DimensionError(ValueError):
     """ValueError regarding wrong dimensions."""
 
-class AutodocError(RuntimeError):
-    """RuntimeError regarding automatic documentation."""
-    
-class DeprecatedAttribute(AttributeError):
-    def __init__(self, old, new):
-        super().__init__(f"'{old}' is deprecated; please use '{new}' instead")
-        
-        
\ No newline at end of file
+def message_with_object_stamp(object, msg):
+    object_name = repr(object)
+    if object_name in msg:
+        return msg
+    else:
+        return colors.violet(object_name) + ' ' + msg
+
+def raise_error_with_object_stamp(object, error):
+    msg, *args = error.args
+    error.args = (message_with_object_stamp(object, msg), *args)
+    raise error
+
+def try_method_with_object_stamp(object, method, args=()):
+    try:
+        return method(*args)
+    except Exception as error:
+        raise_error_with_object_stamp(object, error)
\ No newline at end of file
